		.msfirst
		
#define EQU     .EQU
#define ORG     .ORG
#define RMB     .BLOCK
#define FCB     .BYTE
#define FCC     .TEXT
#define FDB     .WORD
#define END		.END

#define equ     .EQU
#define org     .ORG
#define rmb     .BLOCK
#define fcb     .BYTE
#define fcc     .TEXT
#define fdb     .WORD
#define	end		.END


TCSR	EQU		$0008		; Timer Control Status Register
TIMER	EQU		$0009		; Counter
OCR	EQU		$000B		; Output Compare Register
OCV	EQU		$4206		; Output Compare interrupt Vector

;MC-10 clock is .89488625Mhz or 894.88625Khz
; We need 2.5Khz interrupts so divide 894.88625 (.89488625 Mhz) by 2.58 = 346.855135... or 347 when rounded.
; subtract 22 to get the value we need or 325 aka $0145
TVAL	EQU		$fff8			0150		; Timer period - 22
TCSRVAL	EQU		$8			; bit settings for the TCSR
SVDP	EQU		$bfff		; sound and VDP control register address

		
		org		$5000
		sei

;******************************************
;* Main
;******************************************
Start:
		ldd		#$01100		;number of interrupts between calls (60Hz conversion)
		std		count60

;******************************************		
; set the Interrupt Control Vector
;******************************************
		LDAA	#$7e	;load 'jmp' instruction opcode
		STAA	OCV		;store into OCV vector
		LDX		#note		; store interrupt hander address after JMP instruction
		STX		OCV+1
;******************************************	
;Enable the timer interrupt
;******************************************
		; set the timer duration
		LDD		#TVAL
		STD		OCR
	
		;reset the counter to $FFF8.
		STAA	TIMER

		
		;Enable the timer interrupt
		LDAA	#TCSRVAL
		STAA	TCSR

		cli					;enable interrupts

		;endless loop

busy:		dec		count60+1
		bne		busy
		dec		count60
		bne		busy
		jsr		play2
		ldd		#$1100		;number of interrupts between calls (60Hz conversion)
		std		count60

		BRA		busy

;******************************************************
;nc/nc 	= no toggle
;nc/c 	= toggle output
;c/nc 	= toggle output
;c/c   	= no toggle
;******************************************************
note		LDAA	TCSR	; ack irq !
		stab	TIMER	; ack timer

		LDD	#TVAL   ; reset 
		STD	OCR	; timer


sum		ldd 	#$0000 
freq		addd 	#$0000
		std 	sum+1	
		bcs	tog	

sum2		ldd	#$0000	
		addd	freq2+1	
		std	sum2+1	
		bcc	notog	

output		ldaa	TSVDP		;get RAM copy of Sound and VDP setting
		eora  	#$80	
		staa	SVDP		;set the hardware


		rti

tog		ldd	sum2+1
freq2		addd	#$0000
		std	sum2+1
		bra	output

notog		ldaa	TSVDP		;get RAM copy of Sound and VDP setting	
		anda	#$7f
		staa	SVDP		;set the hardware


		rti


	
;************************************************
; OK SO FAR
;************************************************
	
play2
	ldx	#NOPAT

curnote	ldd	,x		;load 2 notes from pattern
	bpl	plnote		;pattern ends with $80 (-ve flag set)

curpat	ldx	#PATTERNS-2	;load pointer to patterns
	inx			
	inx			;bump pattern
	cpx	#PAT0-2		;end of patterns, time to loop
	blo	nxpat

	ldx	#PATTERNS	;first pattern (rem out for loop to another point)
nxpat	stx	curpat+1
	ldx	,x		;load pointer to notes
	ldd	,x		;(replace with bra curnote if there are ever blank patterns)

plnote	inx
	inx
	stx	play2+1
	asld			;*2 for for lookup
	staa	ok1+1
	stab	ok2+1

	ldx	#freqtab	;freq table pointer	
ok1	ldd	0,x		;get the right freq
stor1	std	freq+1		;store
ok2	ldd	0,x		;get the freq for chan2
stor2	std	freq2+1
;************************************************

out	 rts


;******************************************************
;equal tempered 12 note per octave frequency table
;******************************************************


count60		FDB	$1100			;Interrupt is at 258Khz.  It takes 43 interrupts to equal 60Hz
TSVDP		fcb 	$00			;Temporary Sound and VDP settings


freqtab
	fdb 0,471,499,529,560,593,629,666,706,748,792,839
	fdb 889,942,998,1057,1120,1187,1258,1332,1412,1495,1584,1679		; B2 -
	fdb 1778,1884,1996,2115,2241,2374,2515,2665,2823,2991,3169,3357		; B3 -
	fdb 3557,3768,3992,4230,4481,4748,5030,5329,5646,5982,6338,6714		; B4 -
	fdb 7114,7537,7985,8460,8963,9496,10060,10658,11292,11964,12675
	fdb 13429,14227,15073,15970	


;******************************************************
; PATTERN POINTERS
;******************************************************


PATLOOP
PATTERNS
	fdb PAT0
	fdb PAT11
	fdb PAT12
	fdb PAT13
	fdb PAT2
	fdb PAT3
	fdb PAT4
	fdb PAT5
	fdb PAT2
	fdb PAT3
	fdb PAT4
	fdb PAT5
	fdb PAT16
	fdb PAT19
	fdb PAT2
	fdb PAT3
	fdb PAT4
	fdb PAT5
	fdb PAT6
	fdb PAT17
	fdb PAT18
	fdb PAT17
	fdb PAT18
	fdb PAT16
	fdb PAT19
	fdb PAT2
	fdb PAT3
	fdb PAT4
	fdb PAT5
	fdb PAT20
	fdb PAT20
	fdb PAT20
	fdb PAT6

PAT0
	fcb $12,$6
	fcb $6,$6
	fcb $12,$0
	fcb $6,$6
	fcb $12,$6
	fcb $6,$0
	fcb $12,$6
	fcb $6,$6
	fcb $12,$0
	fcb $6,$6
	fcb $12,$6
	fcb $6,$0
	fcb $12,$6
	fcb $6,$6
	fcb $12,$0
	fcb $6,$6
	fcb $12,$6
	fcb $6,$0
	fcb $12,$6
	fcb $6,$6
	fcb $12,$0
	fcb $6,$6
	fcb $12,$6
	fcb $6,$0
	fcb $12,$6
	fcb $6,$6
	fcb $12,$0
	fcb $6,$6
	fcb $12,$6
	fcb $6,$0
	fcb $12,$6
	fcb $6,$6
	fcb $12,$0
	fcb $6,$6
	fcb $12,$6
	fcb $6,$0
	fcb $12,$6
	fcb $6,$6
	fcb $12,$0
	fcb $6,$6
	fcb $12,$6
	fcb $6,$0
	fcb $12,$6
	fcb $6,$6
	fcb $12,$0
	fcb $6,$6
	fcb $12,$6
	fcb $6,$0
NOPAT	fcb $80,$00

PAT2
	fcb $12,$2a
	fcb $6,$1e
	fcb $12,$0
	fcb $6,$0
	fcb $12,$2a
	fcb $6,$1e
	fcb $12,$0
	fcb $6,$0
	fcb $12,$0
	fcb $6,$0
	fcb $12,$2a
	fcb $6,$1e
	fcb $12,$2d
	fcb $6,$21
	fcb $12,$0
	fcb $6,$0
	fcb $12,$2d
	fcb $6,$21
	fcb $12,$0
	fcb $6,$0
	fcb $12,$0
	fcb $6,$0
	fcb $12,$2d
	fcb $6,$21
	fcb $12,$2c
	fcb $6,$20
	fcb $12,$0
	fcb $6,$0
	fcb $12,$2c
	fcb $6,$20
	fcb $12,$2f
	fcb $6,$23
	fcb $12,$0
	fcb $6,$0
	fcb $12,$2f
	fcb $6,$23
	fcb $12,$0
	fcb $6,$0
	fcb $12,$0
	fcb $6,$0
	fcb $12,$2d
	fcb $6,$21
	fcb $12,$34
	fcb $6,$28
	fcb $12,$0
	fcb $6,$0
	fcb $12,$34
	fcb $6,$28
	fcb $80,$00

PAT3
	fcb $15,$2a
	fcb $9,$1e
	fcb $15,$0
	fcb $9,$0
	fcb $15,$2a
	fcb $9,$1e
	fcb $15,$0
	fcb $9,$0
	fcb $15,$0
	fcb $9,$0
	fcb $15,$2a
	fcb $9,$1e
	fcb $15,$2d
	fcb $9,$21
	fcb $15,$0
	fcb $9,$0
	fcb $15,$2d
	fcb $9,$21
	fcb $15,$0
	fcb $9,$0
	fcb $15,$0
	fcb $9,$0
	fcb $15,$2d
	fcb $9,$21
	fcb $15,$2c
	fcb $9,$20
	fcb $15,$0
	fcb $9,$0
	fcb $15,$2c
	fcb $9,$20
	fcb $15,$2f
	fcb $9,$23
	fcb $15,$0
	fcb $9,$0
	fcb $15,$2f
	fcb $9,$23
	fcb $15,$0
	fcb $9,$0
	fcb $15,$0
	fcb $9,$0
	fcb $15,$2d
	fcb $9,$21
	fcb $15,$34
	fcb $9,$28
	fcb $15,$0
	fcb $9,$0
	fcb $15,$34
	fcb $9,$28
	fcb $80,$00

PAT4
	fcb $10,$2a
	fcb $4,$1e
	fcb $10,$0
	fcb $4,$0
	fcb $10,$2a
	fcb $4,$1e
	fcb $10,$0
	fcb $4,$0
	fcb $10,$0
	fcb $4,$0
	fcb $10,$2a
	fcb $4,$1e
	fcb $10,$2d
	fcb $4,$21
	fcb $10,$0
	fcb $4,$0
	fcb $10,$2d
	fcb $4,$21
	fcb $10,$0
	fcb $4,$0
	fcb $10,$0
	fcb $4,$0
	fcb $10,$2d
	fcb $4,$21
	fcb $10,$2c
	fcb $4,$20
	fcb $10,$0
	fcb $4,$0
	fcb $10,$2c
	fcb $4,$20
	fcb $10,$2f
	fcb $4,$23
	fcb $10,$0
	fcb $4,$0
	fcb $10,$2f
	fcb $4,$23
	fcb $10,$0
	fcb $4,$0
	fcb $10,$0
	fcb $4,$0
	fcb $10,$2d
	fcb $4,$21
	fcb $10,$34
	fcb $4,$28
	fcb $10,$0
	fcb $4,$0
	fcb $10,$34
	fcb $4,$28
	fcb $80,$00

PAT5
	fcb $f,$2a
	fcb $3,$1e
	fcb $f,$0
	fcb $3,$0
	fcb $f,$2a
	fcb $3,$1e
	fcb $f,$0
	fcb $3,$0
	fcb $f,$0
	fcb $3,$0
	fcb $f,$2a
	fcb $3,$1e
	fcb $f,$2d
	fcb $3,$21
	fcb $f,$0
	fcb $3,$0
	fcb $f,$2d
	fcb $3,$21
	fcb $f,$0
	fcb $3,$0
	fcb $f,$0
	fcb $3,$0
	fcb $f,$2d
	fcb $3,$21
	fcb $f,$2c
	fcb $3,$20
	fcb $f,$0
	fcb $3,$0
	fcb $f,$2c
	fcb $3,$20
	fcb $f,$2f
	fcb $3,$23
	fcb $f,$0
	fcb $3,$0
	fcb $f,$2f
	fcb $3,$23
	fcb $f,$0
	fcb $3,$0
	fcb $f,$0
	fcb $3,$0
	fcb $f,$2d
	fcb $3,$21
	fcb $f,$34
	fcb $3,$28
	fcb $f,$0
	fcb $3,$0
	fcb $f,$34
	fcb $3,$28
	fcb $80,$00

PAT6
	fcb $0,$2a
	fcb $0,$1e
	fcb $0,$0
	fcb $0,$0
	fcb $0,$2a
	fcb $0,$1e
	fcb $0,$0
	fcb $0,$0
	fcb $0,$0
	fcb $0,$0
	fcb $0,$2a
	fcb $0,$1e
	fcb $0,$2d
	fcb $0,$21
	fcb $0,$0
	fcb $0,$0
	fcb $0,$2d
	fcb $0,$21
	fcb $0,$0
	fcb $0,$0
	fcb $0,$0
	fcb $0,$0
	fcb $0,$2d
	fcb $0,$21
	fcb $0,$2c
	fcb $0,$20
	fcb $0,$0
	fcb $0,$0
	fcb $0,$2c
	fcb $0,$20
	fcb $0,$2f
	fcb $0,$23
	fcb $0,$0
	fcb $0,$0
	fcb $0,$2f
	fcb $0,$23
	fcb $0,$0
	fcb $0,$0
	fcb $0,$0
	fcb $0,$0
	fcb $0,$2d
	fcb $0,$21
	fcb $0,$34
	fcb $0,$28
	fcb $0,$0
	fcb $0,$0
	fcb $0,$34
	fcb $0,$28
	fcb $80,$00

PAT11
	fcb $15,$9
	fcb $9,$9
	fcb $15,$0
	fcb $9,$9
	fcb $15,$9
	fcb $9,$0
	fcb $15,$9
	fcb $9,$9
	fcb $15,$0
	fcb $9,$9
	fcb $15,$9
	fcb $9,$0
	fcb $15,$9
	fcb $9,$9
	fcb $15,$0
	fcb $9,$9
	fcb $15,$9
	fcb $9,$0
	fcb $15,$9
	fcb $9,$9
	fcb $15,$0
	fcb $9,$9
	fcb $15,$9
	fcb $9,$0
	fcb $15,$9
	fcb $9,$9
	fcb $15,$0
	fcb $9,$9
	fcb $15,$9
	fcb $9,$0
	fcb $15,$9
	fcb $9,$9
	fcb $15,$0
	fcb $9,$9
	fcb $15,$9
	fcb $9,$0
	fcb $15,$9
	fcb $9,$9
	fcb $15,$0
	fcb $9,$9
	fcb $15,$9
	fcb $9,$0
	fcb $15,$9
	fcb $9,$9
	fcb $15,$0
	fcb $9,$9
	fcb $15,$9
	fcb $9,$0
	fcb $80,$00

PAT12
	fcb $10,$4
	fcb $4,$4
	fcb $10,$0
	fcb $4,$4
	fcb $10,$4
	fcb $4,$0
	fcb $10,$4
	fcb $4,$4
	fcb $10,$0
	fcb $4,$4
	fcb $10,$4
	fcb $4,$0
	fcb $10,$4
	fcb $4,$4
	fcb $10,$0
	fcb $4,$4
	fcb $10,$4
	fcb $4,$0
	fcb $10,$4
	fcb $4,$4
	fcb $10,$0
	fcb $4,$4
	fcb $10,$4
	fcb $4,$0
	fcb $10,$4
	fcb $4,$4
	fcb $10,$0
	fcb $4,$4
	fcb $10,$4
	fcb $4,$0
	fcb $10,$4
	fcb $4,$4
	fcb $10,$0
	fcb $4,$4
	fcb $10,$4
	fcb $4,$0
	fcb $10,$4
	fcb $4,$4
	fcb $10,$0
	fcb $4,$4
	fcb $10,$4
	fcb $4,$0
	fcb $10,$4
	fcb $4,$4
	fcb $10,$0
	fcb $4,$4
	fcb $10,$4
	fcb $4,$0
	fcb $80,$00

PAT13
	fcb $f,$3
	fcb $3,$3
	fcb $f,$0
	fcb $3,$3
	fcb $f,$3
	fcb $3,$0
	fcb $f,$3
	fcb $3,$3
	fcb $f,$0
	fcb $3,$3
	fcb $f,$3
	fcb $3,$0
	fcb $f,$3
	fcb $3,$3
	fcb $f,$0
	fcb $3,$3
	fcb $f,$3
	fcb $3,$0
	fcb $f,$3
	fcb $3,$3
	fcb $f,$0
	fcb $3,$3
	fcb $f,$3
	fcb $3,$0
	fcb $f,$3
	fcb $3,$3
	fcb $f,$0
	fcb $3,$3
	fcb $f,$3
	fcb $3,$0
	fcb $f,$3
	fcb $3,$3
	fcb $f,$0
	fcb $3,$3
	fcb $f,$3
	fcb $3,$0
	fcb $f,$3
	fcb $3,$3
	fcb $f,$0
	fcb $3,$3
	fcb $f,$3
	fcb $3,$0
	fcb $f,$3
	fcb $3,$3
	fcb $f,$0
	fcb $3,$3
	fcb $f,$3
	fcb $3,$0
	fcb $80,$00

PAT16
	fcb $12,$36
	fcb $6,$1e
	fcb $12,$1e
	fcb $6,$1e
	fcb $12,$36
	fcb $6,$1e
	fcb $12,$0
	fcb $6,$0
	fcb $12,$0
	fcb $6,$1e
	fcb $12,$1e
	fcb $6,$0
	fcb $12,$36
	fcb $6,$36
	fcb $12,$0
	fcb $6,$1e
	fcb $12,$1e
	fcb $6,$0
	fcb $12,$2a
	fcb $6,$1e
	fcb $12,$0
	fcb $6,$6
	fcb $12,$6
	fcb $6,$0
	fcb $12,$6
	fcb $6,$6
	fcb $12,$0
	fcb $6,$6
	fcb $12,$6
	fcb $6,$0
	fcb $12,$6
	fcb $6,$6
	fcb $12,$0
	fcb $6,$2a
	fcb $12,$2a
	fcb $6,$0
	fcb $12,$6
	fcb $6,$6
	fcb $12,$0
	fcb $6,$2a
	fcb $12,$2a
	fcb $6,$0
	fcb $12,$36
	fcb $6,$36
	fcb $12,$0
	fcb $6,$1e
	fcb $12,$1e
	fcb $6,$0
	fcb $80,$00

PAT17
	fcb $12,$1e
	fcb $6,$21
	fcb $12,$25
	fcb $6,$1e
	fcb $12,$21
	fcb $6,$25
	fcb $12,$1e
	fcb $6,$21
	fcb $12,$25
	fcb $6,$1e
	fcb $12,$21
	fcb $6,$25
	fcb $12,$1e
	fcb $6,$21
	fcb $12,$25
	fcb $6,$1e
	fcb $12,$21
	fcb $6,$25
	fcb $12,$1e
	fcb $6,$21
	fcb $12,$25
	fcb $6,$1e
	fcb $12,$21
	fcb $6,$25
	fcb $12,$1e
	fcb $6,$21
	fcb $12,$25
	fcb $6,$1e
	fcb $12,$21
	fcb $6,$25
	fcb $12,$1e
	fcb $6,$21
	fcb $12,$25
	fcb $6,$1e
	fcb $12,$21
	fcb $6,$25
	fcb $12,$1e
	fcb $6,$21
	fcb $12,$25
	fcb $6,$1e
	fcb $12,$21
	fcb $6,$25
	fcb $12,$1e
	fcb $6,$21
	fcb $12,$25
	fcb $6,$1e
	fcb $12,$21
	fcb $6,$25
	fcb $80,$00

PAT18
	fcb $15,$21
	fcb $9,$25
	fcb $15,$28
	fcb $9,$21
	fcb $15,$25
	fcb $9,$28
	fcb $15,$21
	fcb $9,$25
	fcb $15,$28
	fcb $9,$21
	fcb $15,$25
	fcb $9,$28
	fcb $15,$21
	fcb $9,$25
	fcb $15,$28
	fcb $9,$21
	fcb $15,$25
	fcb $9,$28
	fcb $15,$21
	fcb $9,$25
	fcb $15,$28
	fcb $9,$21
	fcb $15,$25
	fcb $9,$28
	fcb $15,$2d
	fcb $9,$25
	fcb $15,$34
	fcb $9,$2d
	fcb $15,$25
	fcb $9,$34
	fcb $15,$2d
	fcb $9,$25
	fcb $15,$34
	fcb $9,$2d
	fcb $15,$25
	fcb $9,$34
	fcb $15,$2d
	fcb $9,$25
	fcb $15,$34
	fcb $9,$2d
	fcb $15,$25
	fcb $9,$34
	fcb $15,$2d
	fcb $9,$25
	fcb $15,$34
	fcb $9,$2d
	fcb $15,$25
	fcb $9,$34
	fcb $80,$00

PAT19
	fcb $12,$36
	fcb $6,$2a
	fcb $12,$2a
	fcb $6,$2a
	fcb $12,$36
	fcb $6,$2a
	fcb $12,$2a
	fcb $6,$2a
	fcb $12,$0
	fcb $6,$1e
	fcb $12,$1e
	fcb $6,$0
	fcb $12,$36
	fcb $6,$36
	fcb $12,$0
	fcb $6,$1e
	fcb $12,$1e
	fcb $6,$0
	fcb $12,$2a
	fcb $6,$2a
	fcb $12,$0
	fcb $6,$1e
	fcb $12,$1e
	fcb $6,$0
	fcb $12,$2a
	fcb $6,$1e
	fcb $12,$0
	fcb $6,$6
	fcb $12,$6
	fcb $6,$0
	fcb $12,$6
	fcb $6,$6
	fcb $12,$0
	fcb $6,$2a
	fcb $12,$2a
	fcb $6,$0
	fcb $12,$6
	fcb $6,$6
	fcb $12,$0
	fcb $6,$2a
	fcb $12,$2a
	fcb $6,$0
	fcb $12,$36
	fcb $6,$36
	fcb $12,$0
	fcb $6,$1e
	fcb $12,$1e
	fcb $6,$0
	fcb $80,$00

PAT20
	fcb $12,$6
	fcb $6,$6
	fcb $12,$0
	fcb $6,$6
	fcb $12,$6
	fcb $6,$0
	fcb $12,$6
	fcb $6,$6
	fcb $12,$0
	fcb $6,$6
	fcb $12,$6
	fcb $6,$0
	fcb $12,$6
	fcb $6,$6
	fcb $12,$0
	fcb $6,$6
	fcb $12,$6
	fcb $6,$0
	fcb $12,$6
	fcb $6,$6
	fcb $12,$0
	fcb $6,$6
	fcb $12,$6
	fcb $6,$0
	fcb $12,$2a
	fcb $6,$1e
	fcb $12,$0
	fcb $6,$2a
	fcb $12,$1e
	fcb $6,$0
	fcb $12,$6
	fcb $6,$6
	fcb $12,$0
	fcb $6,$6
	fcb $12,$6
	fcb $6,$0
	fcb $12,$6
	fcb $6,$6
	fcb $12,$0
	fcb $6,$6
	fcb $12,$6
	fcb $6,$0
	fcb $12,$6
	fcb $6,$6
	fcb $12,$0
	fcb $6,$6
	fcb $12,$6
	fcb $6,$0
	fcb $80,$00




	.end	
	
